==> elephantdsp-roomreverb-debug-1.1.0-1-x86_64.pkg.tar.zst: usr/src/debug/elephantdsp-roomreverb/elephantdsp-roomreverb/Source/PluginEditor.h <==
/**
 *  ElephantDSP.com Room Reverb
 *
 *  Copyright (C) 2021 Christian Voigt
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "Components/Main.h"
#include "LookAndFeel/CustomLookAndFeel.h"
#include "PluginProcessor.h"
#include <juce_audio_processors/juce_audio_processors.h>

class ReverbAudioProcessorEditor : public juce::AudioProcessorEditor
{
public:
    ReverbAudioProcessorEditor(ReverbAudioProcessor& audioProcessor);
    ~ReverbAudioProcessorEditor() override;

    //==============================================================================
    void paint(juce::Graphics& g) override;
    void resized() override;

private:
    CustomLookAndFeel customLookAndFeel;
    juce::ValueTree& applicationState;
    Main main;

    const int idealWidth = 1024;
    const int idealHeight = 768;
    const int minWidth = 800;
    const int minHeight = 600;

    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR(ReverbAudioProcessorEditor)
};

==> elephantdsp-roomreverb-debug-1.4.1-1-x86_64.pkg.tar.zst: usr/src/debug/elephantdsp-roomreverb/elephantdsp-roomreverb/Source/PluginEditor.h <==
/**
 *  ElephantDSP.com Room Reverb
 *
 *  Copyright (C) 2021 Christian Voigt
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "Components/Main.h"
#include "LookAndFeel/CustomLookAndFeel.h"
#include "PluginProcessor.h"
#include <juce_audio_processors/juce_audio_processors.h>

class ReverbAudioProcessorEditor : public juce::AudioProcessorEditor
{
public:
    ReverbAudioProcessorEditor(ReverbAudioProcessor& audioProcessor);
    ~ReverbAudioProcessorEditor() override;

    //==============================================================================
    void paint(juce::Graphics& g) override;
    void resized() override;

private:
    CustomLookAndFeel mCustomLookAndFeel;
    juce::ValueTree& mApplicationState;
    Main mMainView;

    static constexpr int IDEAL_WIDTH = 1024;
    static constexpr int IDEAL_HEIGHT = 768;
    static constexpr int MIN_WIDTH = 800;
    static constexpr int MIN_HEIGHT = 600;

    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR(ReverbAudioProcessorEditor)
};
